# Chunked Primitive Arrays

Chunked arrays of non-geospatial types. These exist to be used as _return_ types
from geospatial operations to maintain strong typing.

- [`ChunkedBooleanArray`](#geoarrow.rust.core.ChunkedBooleanArray)
<!-- - [`ChunkedFloat16Array`](#geoarrow.rust.core.ChunkedFloat16Array)
- [`ChunkedFloat32Array`](#geoarrow.rust.core.ChunkedFloat32Array) -->
- [`ChunkedFloat64Array`](#geoarrow.rust.core.ChunkedFloat64Array)
<!-- - [`ChunkedUInt8Array`](#geoarrow.rust.core.ChunkedUInt8Array)
- [`ChunkedUInt16Array`](#geoarrow.rust.core.ChunkedUInt16Array)
- [`ChunkedUInt32Array`](#geoarrow.rust.core.ChunkedUInt32Array)
- [`ChunkedUInt64Array`](#geoarrow.rust.core.ChunkedUInt64Array)
- [`ChunkedInt8Array`](#geoarrow.rust.core.ChunkedInt8Array)
- [`ChunkedInt16Array`](#geoarrow.rust.core.ChunkedInt16Array)
- [`ChunkedInt32Array`](#geoarrow.rust.core.ChunkedInt32Array)
- [`ChunkedInt64Array`](#geoarrow.rust.core.ChunkedInt64Array)
- [`ChunkedStringArray`](#geoarrow.rust.core.ChunkedStringArray)
- [`ChunkedLargeStringArray`](#geoarrow.rust.core.ChunkedLargeStringArray) -->

::: geoarrow.rust.core
    options:
      filters:
        - "!^_"
        - "^__arrow"
      members:
        - ChunkedBooleanArray
        - ChunkedFloat64Array
